@@ -143,7 +143,9 @@ select T.create_date,
        D.object_id as default_constraint_object_id,
        D.modify_date default_constraint_modify_date,
        coalesce(D.definition, X.definition) as default_expression,
-       #V13: C.is_hidden #: 0 #. as is_hidden
+       #V13: C.is_hidden #: 0 #. as is_hidden,
+       #V13: C.is_sparse #: 0 #. as is_sparse,
+       #V13: C.is_column_set #: 0 #. as is_column_set
 from T join #CAT.all_columns C on T.object_id = C.object_id
        left outer join #CAT.types Y on C.system_type_id = Y.system_type_id and C.user_type_id = Y.user_type_id
        left outer join #CAT.identity_columns I on C.object_id = I.object_id and C.column_id = I.column_id
@@ -469,8 +471,42 @@ where schema_id = :schema_id
   and modify_date >= :since
 ;
 
+---- RetrieveSequences ----
+select
+  Q.name,
+  Q.object_id,
+  Q.create_date,
+  q.modify_date,
+  Q.current_value,
+  Q.increment,
+  Q.minimum_value,
+  Q.maximum_value,
+  Q.is_cycling,
+  Q.is_cached,
+  Q.cache_size,
+  TS.name as system_type_name,
+  T.name as type_name,
+  S.name as type_schema_name,
+  Q.precision
+from
+  sys.sequences Q
+      join sys.types TS on TS.system_type_id = Q.system_type_id
+      join sys.types T on T.user_type_id = Q.user_type_id
+      join sys.schemas S on S.schema_id = T.schema_id
+where
+  Q.schema_id = :schema_id and TS.is_user_defined = 0
 
----- CalculateDescriptionsChecksum ----
+---- RetrieveRules ----
+select object_id,
+       name,
+       create_date,
+       modify_date
+from #CAT.objects
+where schema_id = :schema_id
+  and type = 'R'
+;
+
+---- CalculateExtendedPropertiesChecksum ----
 select sum(abs(cast(checksum(major_id, minor_id, cast(value as varchar(40))) as bigint))) as checksum
 from #CAT.extended_properties X
      left join #CAT.all_objects O
@@ -482,15 +518,14 @@ from #CAT.extended_properties X
         on T.user_type_id = X.major_id
        and X.class = 6
 where coalesce(O.schema_id, T.schema_id, case when X.class = 3 then X.major_id else null end) = :schema_id
-  and X.name = N'MS_Description'
   and X.value is not null
 ;
 
 
----- RetrieveDescriptions ----
+---- RetrieveExtendedProperties ----
 select X.major_id object_id,
        case when X.class = 7 then -1 else 1 end*(X.minor_id % 30000) as position,
-       cast(X.value as varchar(max)) as description
+       X.name as name, cast(X.value as varchar(max)) as value, SQL_VARIANT_PROPERTY(X.value, 'BaseType') as type
 from #CAT.extended_properties X
      left join #CAT.all_objects O
         on O.object_id = X.major_id
@@ -501,7 +536,14 @@ from #CAT.extended_properties X
         on T.user_type_id = X.major_id
        and X.class = 6
 where (coalesce(O.schema_id, T.schema_id, case when X.class = 3 then X.major_id else null end) = :schema_id)
-  and X.name = N'MS_Description'
+  and X.value is not null
+;
+
+---- RetrieveDbExtendedProperties ----
+select X.major_id object_id, X.minor_id as position,
+       X.name as name, cast(X.value as varchar(max)) as value, SQL_VARIANT_PROPERTY(X.value, 'BaseType') as type
+from #CAT.extended_properties X
+where X.class = 0
   and X.value is not null
 ;
 
