@@ -21,6 +21,26 @@ where UR.username = user
 /
 
 
+---- CheckFastDictionariesAccess ----
+with V1 as (select 0 from sys.obj$ where 1 is null),
+     V2 as (select 0 from sys.type$ where 1 is null),
+     V3 as (select 0 from sys.ind$ where 1 is null),
+     V4 as (select 0 from sys.ts$ where 1 is null),
+     V5 as (select 0 from sys.con$ where 1 is null),
+     V6 as (select 0 from sys.cdef$ where 1 is null),
+     V7 as (select 0 from sys.dependency$ where 1 is null)
+select 1
+from dual
+where not exists (select 1 from V1)
+  and not exists (select 1 from V2)
+  and not exists (select 1 from V3)
+  and not exists (select 1 from V4)
+  and not exists (select 1 from V5)
+  and not exists (select 1 from V6)
+  and not exists (select 1 from V7)
+/
+
+
 ---- RetrieveAllSchemas ----
 select id, name
 from ( select user_id as id, username as name from sys.all_users
@@ -80,13 +100,13 @@ where O.owner# in ( :[*all_schema_ids] )
 /
 
 
----- RetrieveAllMajorNamesSlow ----
+---- RetrieveAllMajorNames ----
 select substr(substr(O.object_type,1,2) ||
                to_char(U.user_id, 'FM0000000000') || to_char(O.object_id, 'FM0000000000') ||
                O.secondary ||
                O.object_name, 1, #N12: 160 #: 60 #.) as item
-from sys.all_objects O,
-     sys.all_users U
+from #CAT_objects O,
+     #CAT_users U
 where U.user_id in ( :[*all_schema_ids] )
   and U.username = O.owner
   and substr(O.object_type,1,2) in ('TA','CL','VI','SE','PR','FU','PA','MA')
@@ -100,9 +120,9 @@ select decode(T.typecode, 'OBJECT','YB', 'YC') ||
        to_char(U.user_id, 'FM0000000000') || to_char(O.object_id, 'FM0000000000') ||
        O.secondary ||
        T.type_name as item
-from sys.all_users U,
-     sys.all_types T,
-     sys.all_objects O
+from #CAT_users U,
+     #CAT_types T,
+     #CAT_objects O
 where U.user_id in ( :[*all_schema_ids] )
   and U.username = T.owner
   and T.type_name = O.object_name
@@ -124,9 +144,9 @@ where #FRAG: owner# = :schema_id #: owner# in ( :[*all_schema_ids] ) #.
 /
 
 
----- RetrieveAllObjectIdentifiersSlow ----
+---- RetrieveAllObjectIdentifiers ----
 select object_id
-from sys.all_objects
+from #CAT_objects
 where #FRAG: owner = :schema_name #: owner in ( :[*all_schema_names] ) #.
   and object_type in ( 'SEQUENCE','CLUSTER','TABLE','INDEX','MATERIALIZED VIEW','VIEW',
                        'TYPE','TYPE BODY','PACKAGE','PACKAGE BODY',
@@ -143,9 +163,9 @@ where obj# in ( :[*object_ids] )
 /
 
 
----- RetrieveStatesSlow ----
+---- RetrieveStates ----
 select object_id, last_ddl_time modified_timestamp
-from sys.all_objects
+from #CAT_objects
 where object_id in ( :[*object_ids] )
 /
 
@@ -661,7 +681,7 @@ where I.table_type = 'CLUSTER'
 /
 
 
----- RetrieveTableClusterColumnsAdmin ----
+---- RetrieveTableClusterColumnsDba ----
 select C.table_name,
        C.tab_column_name as column_name
 from sys.dba_clu_columns C, -- table clustering column
@@ -835,7 +855,7 @@ where CN.owner# = :schema_id
 /
 
 
----- RetrieveForeignKeysSlow ----
+---- RetrieveForeignKeys ----
 with my_tables as ( select owner, object_id as table_id, object_name as table_name
                     from #CAT_objects
                     where owner = :schema_name
@@ -1114,19 +1134,19 @@ order by object_id, #V11:subprogram_id,#. position
 
 ---- CalculateCommentsHash ----
 with OI as ( select object_name as table_name, object_id
-             from all_objects
+             from #CAT_objects
              where owner = :schema_name
                and object_type in ('TABLE', 'MATERIALIZED VIEW', 'VIEW') ),
      X1 as ( select sum(object_id * 1007 +
                         dbms_utility.get_hash_value(comments, 1, 1073741824)) as X
-             from all_tab_comments natural join OI
+             from #CAT_tab_comments natural join OI
              where owner = :schema_name
                and table_name not like 'BIN$%'
                and comments is not null ),
      X2 as ( select sum(object_id * 10007 +
                         dbms_utility.get_hash_value(column_name,1,1073741824) * 101 +
                         dbms_utility.get_hash_value(comments,1,1073741824)) as X
-             from all_col_comments natural join OI
+             from #CAT_col_comments natural join OI
              where owner = :schema_name
                and table_name not like 'BIN$%'
                and comments is not null )
@@ -1292,7 +1312,7 @@ where owner# = :schema_id
   and name not like 'BIN$%'
 /
 
----- ListInvalidObjectsSlow ----
+---- ListInvalidObjects ----
 select object_id
 from #CAT_objects
 where owner = :schema_name
@@ -1313,6 +1333,17 @@ order by name, type, sequence, line, position
 /
 
 
+---- RetrieveDebugInfoPresence ----
+select decode(debugInfo, 'F', -object_id, 'T', +object_id, null) as id
+from sys.all_probe_objects
+where owner = :schema_name
+  #INC> and last_ddl_time >= :src_since
+  #FRAG> and object_name in ( :[*major_object_names] )
+  and object_id > 0
+  and debugInfo in ('F', 'T')
+/
+
+
 ---- RetrieveNativeDefinitions ----
 with O as ( select object_id, object_type, owner, object_name
             from #CAT_objects
